@@ -115,12 +115,16 @@ class ElmoClient:
                 {
                     "areas": False,
                     "inputs": True,
+                    "outputs": False,
+                    "statusAdv": False,
                 }
         """
         payload = {
             "sessionId": self._session_id,
             "Areas": ids[q.SECTORS],
             "Inputs": ids[q.INPUTS],
+            "Outputs": ids[q.OUTPUTS],
+            "StatusAdv": ids[q.ALERTS],
             "CanElevate": "1",
             "ConnectionStatus": "1",
         }
@@ -132,9 +136,11 @@ class ElmoClient:
         state = response.json()
         try:
             update = {
-                "has_changes": state["Areas"] or state["Inputs"],
+                "has_changes": state["Areas"] or state["Inputs"] or state["Outputs"] or state["StatusAdv"],
                 "areas": state["Areas"],
                 "inputs": state["Inputs"],
+                "outputs": state["Outputs"],
+                "statusadv": state["StatusAdv"],
             }
         except KeyError as err:
             raise ParseError(f"Client | Unable to parse poll response: {err} is missing") from err
@@ -224,50 +230,43 @@ class ElmoClient:
         Args:
             sector: (optional) list of sectors that must be armed. If the variable is
             empty, ALL is assumed and the entire system is armed. If multiple items
-            are in the list, multiple requests are sent to arm given sectors.
+            are in the list, one request are sent to arm given sectors.
         Raises:
             HTTPError: if there is an error raised by the API (not 2xx response).
         Returns:
             A boolean if the system has been armed correctly.
         """
-        payloads = []
         sectors = sectors or []
 
         if sectors:
             # Arm only selected sectors
             _LOGGER.debug(f"Client | Arming sectors: {sectors}")
-            for sector in sectors:
-                payloads.append(
-                    {
-                        "CommandType": 1,
-                        "ElementsClass": 9,
-                        "ElementsIndexes": sector,
-                        "sessionId": self._session_id,
-                    }
-                )
+            payload = {
+                "CommandType": 1,
+                "ElementsClass": 9,
+                "ElementsIndexes": sectors,
+                "sessionId": self._session_id,
+            }
         else:
             # Arm ALL sectors
             _LOGGER.debug("Client | Arming all sectors")
-            payloads = [
-                {
-                    "CommandType": 1,
-                    "ElementsClass": 1,
-                    "ElementsIndexes": 1,
-                    "sessionId": self._session_id,
-                }
-            ]
+            payload = {
+                "CommandType": 1,
+                "ElementsClass": 1,
+                "ElementsIndexes": 1,
+                "sessionId": self._session_id,
+            }
+
+        # Send the payload to arm sectors
+        response = self._session.post(self._router.send_command, data=payload)
+        response.raise_for_status()
 
-        # Arming multiple sectors requires multiple requests
         errors = []
-        for payload in payloads:
-            response = self._session.post(self._router.send_command, data=payload)
-            response.raise_for_status()
-
-            # A not existing sector returns 200 with a fail state
-            body = response.json()
-            _LOGGER.debug(f"Client | Arming response: {body}")
-            if not body[0]["Successful"]:
-                errors.append(payload["ElementsIndexes"])
+        # A not existing sector returns 200 with a fail state
+        body = response.json()
+        _LOGGER.debug(f"Client | Arming response: {body}")
+        if not body[0]["Successful"]:
+            errors.append(payload["ElementsIndexes"])
 
         # Raise an exception if errors are detected
         if errors:
@@ -296,44 +295,38 @@ class ElmoClient:
         Returns:
             A boolean if the system has been disarmed correctly.
         """
-        payloads = []
         sectors = sectors or []
 
         if sectors:
             # Disarm only selected sectors
             _LOGGER.debug(f"Client | Disarming sectors: {sectors}")
-            for sector in sectors:
-                payloads.append(
-                    {
-                        "CommandType": 2,
-                        "ElementsClass": 9,
-                        "ElementsIndexes": sector,
-                        "sessionId": self._session_id,
-                    }
-                )
+            payload = {
+                "CommandType": 2,
+                "ElementsClass": 9,
+                "ElementsIndexes": sectors,
+                "sessionId": self._session_id,
+            }
+
         else:
             # Disarm ALL sectors
             _LOGGER.debug("Client | Disarming all sectors")
-            payloads = [
-                {
-                    "CommandType": 2,
-                    "ElementsClass": 1,
-                    "ElementsIndexes": 1,
-                    "sessionId": self._session_id,
-                }
-            ]
+            payload = {
+                "CommandType": 2,
+                "ElementsClass": 1,
+                "ElementsIndexes": 1,
+                "sessionId": self._session_id,
+            }
+
+        # Send the payload to disarm sectors
+        response = self._session.post(self._router.send_command, data=payload)
+        response.raise_for_status()
 
-        # Disarming multiple sectors requires multiple requests
         errors = []
-        for payload in payloads:
-            response = self._session.post(self._router.send_command, data=payload)
-            response.raise_for_status()
-
-            # A not existing sector returns 200 with a fail state
-            body = response.json()
-            _LOGGER.debug(f"Client | Disarming response: {body}")
-            if not body[0]["Successful"]:
-                errors.append(payload["ElementsIndexes"])
+        # A not existing sector returns 200 with a fail state
+        body = response.json()
+        _LOGGER.debug(f"Client | Disarming response: {body}")
+        if not body[0]["Successful"]:
+            errors.append(payload["ElementsIndexes"])
 
         # Raise an exception if errors are detected
         if errors:
@@ -459,6 +452,111 @@ class ElmoClient:
         _LOGGER.debug("Client | Including successful")
         return True
 
+    @require_session
+    def turn_on(self, outputs):
+        """Turn on passed outputs
+
+        This API provides the same effects as turning them
+        from "not active" to "active" on the E-Connect web UI.
+
+        Only outputs that are configured in the control panel with the option
+        "Manual Control" can be turned on
+        If the output is configured with "Require Authentication" flag in the control panel
+        can be turned on only if the panel is locked
+
+            client.turn_on([3])  # Turn on only output 3
+            client.turn_on([3, 5])  # Turn on output 3 and 5
+
+        Args:
+            outputs: list of outputs that must be turned on. If multiple items
+            are in the list, one requests is sent to turn on given outputs.
+        Raises:
+            HTTPError: if there is an error raised by the API (not 2xx response).
+        Returns:
+            A boolean if the output has been turned on correctly.
+        """
+
+        # Exclude only selected inputs
+        _LOGGER.debug(f"Client | Turning on outputs: {outputs}")
+        payload = {
+            "CommandType": 1,
+            "ElementsClass": 12,
+            "ElementsIndexes": outputs,
+            "sessionId": self._session_id,
+        }
+
+        errors = []
+
+        # Send turn on request
+        response = self._session.post(self._router.send_command, data=payload)
+        response.raise_for_status()
+
+        # A not existing output returns 200 with a fail state
+        body = response.json()
+        _LOGGER.debug(f"Client | Turning on response: {body}")
+        if not body[0]["Successful"]:
+            errors.append(payload["ElementsIndexes"])
+
+        # Raise an exception if errors are detected
+        if errors:
+            invalid_outputs = ",".join(str(x) for x in errors)
+            raise InvalidInput("Selected outputs don't exist: {}".format(invalid_outputs))
+
+        _LOGGER.debug("Client | Turning on output successful")
+        return True
+
+    @require_session
+    def turn_off(self, outputs):
+        """Turn off passed outputs
+
+        This API provides the same effects as turning them
+        from "active" to "not active" on the E-Connect web UI.
+
+        Only outputs that are configured in the control panel with the option
+        "Manual Control" can be turned off
+        If the output is configured with "Require Authentication" flag in the control panel
+        can be turned off only if the panel is locked
+
+            client.turn_off([3])  # Turn off only output 3
+            client.turn_off([3, 5])  # Turn off output 3 and 5
+
+        Args:
+            outputs: list of outputs that must be turned off. If multiple items
+            are in the list, one requests is sent to turn off given outputs.
+        Raises:
+            HTTPError: if there is an error raised by the API (not 2xx response).
+        Returns:
+            A boolean if the output has been turned off correctly.
+        """
+
+        # Turn off only selected outputs
+        _LOGGER.debug(f"Client | Turning off outputs: {outputs}")
+        payload = {
+            "CommandType": 2,
+            "ElementsClass": 12,
+            "ElementsIndexes": outputs,
+            "sessionId": self._session_id,
+        }
+
+        # Send turn off request
+        response = self._session.post(self._router.send_command, data=payload)
+        response.raise_for_status()
+
+        errors = []
+        # A not existing output returns 200 with a fail state
+        body = response.json()
+        _LOGGER.debug(f"Client | Turning off response: {body}")
+        if not body[0]["Successful"]:
+            errors.append(payload["ElementsIndexes"])
+
+        # Raise an exception if errors are detected
+        if errors:
+            invalid_outputs = ",".join(str(x) for x in errors)
+            raise InvalidInput("Selected outputs don't exist: {}".format(invalid_outputs))
+
+        _LOGGER.debug("Client | Turning off output successful")
+        return True
+
     @lru_cache(maxsize=1)
     @require_session
     def _get_descriptions(self):
@@ -497,49 +595,33 @@ class ElmoClient:
 
             sectors = client.query(query.SECTORS).get("sectors")
             inputs = client.query(query.INPUTS).get("inputs")
+            outputs = client.query(query.OUTPUTS).get("outputs")
 
         Raises:
             QueryNotValid: if the query is not recognized.
             HTTPError: if there is an error raised by the API (not 2xx response).
             ParseError: if the response cannot be parsed because the format is unexpected.
         Returns:
-            A dict representing the raw query retrieved by the backend call. The structure is the following:
-                {
-                    'last_id': 3,
-                    'sectors': {
-                        0: {
-                            'id': 1,
-                            'index': 0,
-                            'element': 1,
-                            'excluded': False,
-                            'status': True,
-                            'name': 'S1 Living Room'
-                        },
-                        1: {
-                            'id': 2,
-                            'index': 1,
-                            'element': 2,
-                            'excluded': False,
-                            'status': True,
-                            'name': 'S2 Bedroom'
-                        },
-                    },
-                }
+            A dict representing the raw query retrieved by the backend call.
+
             `last_id`: is the last ID of the query, used to retrieve new state changes
             `sectors`: is the key you use to retrieve sectors if that was the query
             `inputs`: is the key you use to retrieve inputs if that was the query
+            'outputs`: is the key you use to retrieve outputs if that was the query
         """
         # Query detection
         if query == q.SECTORS:
-            status = "Active"
             key_group = "sectors"
             endpoint = self._router.sectors
             _LOGGER.debug("Client | Querying sectors")
         elif query == q.INPUTS:
-            status = "Alarm"
             key_group = "inputs"
             endpoint = self._router.inputs
             _LOGGER.debug("Client | Querying inputs")
+        elif query == q.OUTPUTS:
+            key_group = "outputs"
+            endpoint = self._router.outputs
+            _LOGGER.debug("Client | Querying outputs")
         elif query == q.ALERTS:
             endpoint = self._router.status
             _LOGGER.debug("Client | Querying alerts")
@@ -550,7 +632,7 @@ class ElmoClient:
         response = self._session.post(endpoint, data={"sessionId": self._session_id})
         response.raise_for_status()
 
-        if query in [q.SECTORS, q.INPUTS]:
+        if query in [q.SECTORS, q.INPUTS, q.OUTPUTS]:
             # Retrieve description or use the cache
             descriptions = self._get_descriptions()
 
@@ -570,19 +652,45 @@ class ElmoClient:
                     if entry["InUse"]:
                         # Address potential data inconsistency between cloud data and main unit.
                         # In some installations, they may be out of sync, resulting in the cloud
-                        # providing a sector/input that doesn't actually exist in the main unit.
+                        # providing a sector/input/output that doesn't actually exist in the main unit.
+                        # This case happens also when all inputs or sectors or outputs are used in the
+                        # main unit, but their strings are not synchronized with the cloud.
                         # To handle this, we default the name to "Unknown" if its description
                         # isn't found in the cloud data to prevent KeyError.
-                        name = descriptions[query].get(entry["Index"], "Unknown")
+                        description = descriptions.get(query, {})
                         item = {
                             "id": entry.get("Id"),
                             "index": entry.get("Index"),
                             "element": entry.get("Element"),
-                            "excluded": entry.get("Excluded", False),
-                            "status": entry.get(status, False),
-                            "name": name,
+                            "name": description.get(entry["Index"], "Unknown"),
                         }
 
+                        if query == q.SECTORS:
+                            item.update(
+                                {
+                                    "activable": entry.get("Activable", False),
+                                    "status": entry.get("Active", False),
+                                }
+                            )
+                            _LOGGER.debug("Client | Querying sectors")
+                        elif query == q.INPUTS:
+                            item.update(
+                                {
+                                    "excluded": entry.get("Excluded", False),
+                                    "status": entry.get("Alarm", False),
+                                }
+                            )
+                            _LOGGER.debug("Client | Querying inputs")
+                        elif query == q.OUTPUTS:
+                            item.update(
+                                {
+                                    "do_not_require_authentication": entry.get("DoNotRequireAuthentication", False),
+                                    "control_denied_to_users": entry.get("ControlDeniedToUsers", False),
+                                    "status": entry.get("Active", False),
+                                }
+                            )
+                            _LOGGER.debug("Client | Querying outputs")
+
                         items[entry.get("Index")] = item
             except KeyError as err:
                 raise ParseError(f"Client | Unable to parse query response: {err}") from err
@@ -593,6 +701,7 @@ class ElmoClient:
             try:
                 # Check if the response has the expected format
                 msg = response.json()
+                last_id = msg["StatusUid"]
                 status = msg["PanelLeds"]
                 anomalies = msg["PanelAnomalies"]
             except (KeyError, ValueError):
@@ -603,8 +712,11 @@ class ElmoClient:
 
             # Convert the dict to a snake_case one to simplify the usage in other modules, and sort alphabetically
             new_dict = {
-                i: {"name": _camel_to_snake_case(k), "status": v}
-                for i, (k, v) in enumerate(sorted(merged_dict.items()))
+                "last_id": last_id,
+                "alerts": {
+                    i: {"name": _camel_to_snake_case(k), "status": v}
+                    for i, (k, v) in enumerate(sorted(merged_dict.items()))
+                },
             }
             _LOGGER.debug(f"Client | Status retrieved: {new_dict}")
 
